@@ -6,10 +6,8 @@
 """
 
 from MoinMoin.Page import Page
-from MoinMoin.util import MoinMoinNoFooter
 
 def execute(pagename, request):
-    url = Page(request, pagename).url(request, {'action': 'format',
-                                                'mimetype': 'xml/docbook'}, 0)
+    url = Page(request, pagename).url(request, {'action': 'show', 'mimetype': 'text/docbook'}, relative=False)
     request.http_redirect(url)
-    raise MoinMoinNoFooter
+
