@@ -4,18 +4,17 @@
 
     Shows the current traceback of all threads.
 
-    @copyright: 2006 by MoinMoin:AlexanderSchremmer
+    @copyright: 2006 MoinMoin:AlexanderSchremmer
     @license: GNU GPL, see COPYING for details.
 """
-
 import os, time
 from StringIO import StringIO
 
-from MoinMoin import wikiutil, util
+from MoinMoin import wikiutil
 from MoinMoin.util import thread_monitor
 
 def execute_fs(pagename, request):
-    if thread_monitor.hook_enabled:
+    if thread_monitor.hook_enabled():
         s = StringIO()
         thread_monitor.trigger_dump(s)
         time.sleep(5) # allow for all threads to dump to request
@@ -28,26 +27,26 @@ def execute_fs(pagename, request):
     else:
         dump_fname = "nowhere"
 
-    request.http_headers()
+    request.emit_http_headers()
     request.write('<html><body>A dump has been saved to %s.</body></html>' % dump_fname)
-    raise util.MoinMoinNoFooter
 
 def execute_wiki(pagename, request):
-    request.http_headers()
+    request.emit_http_headers()
 
-    wikiutil.send_title(request, "Thread monitor")
+    request.theme.send_title("Thread monitor")
     request.write('<pre>')
 
-    if not thread_monitor.hook_enabled:
+    if not thread_monitor.hook_enabled():
         request.write("Hook is not enabled.")
     else:
         s = StringIO()
         thread_monitor.trigger_dump(s)
         time.sleep(5) # allow for all threads to dump to request
         request.write(wikiutil.escape(s.getvalue()))
-        
+
     request.write('</pre>')
-    wikiutil.send_footer(request, pagename)
+    request.theme.send_footer(pagename)
+    request.theme.send_closing_html()
 
 execute = execute_fs
 
