@@ -4,7 +4,7 @@
 
     This macro creates charts from the data in "event.log".
 
-    @copyright: 2002-2004 by Jrgen Hermann <jh@web.de>
+    @copyright: 2002-2004 Juergen Hermann <jh@web.de>
     @license: GNU GPL, see COPYING for details.
 """
 
@@ -18,13 +18,15 @@ def execute(macro, args, **kw):
 
     if not args:
         return (formatter.sysmsg(1) +
-                formatter.text(_('You need to provide a chart type!')) +
+                formatter.text(_('You need to provide a chart type!', formatted=False)) +
                 formatter.sysmsg(0))
 
-    func = pysupport.importName("MoinMoin.stats." + args, "linkto")
-    if not func:
+    try:
+        # stats module without 'linkto' will raise AttributeError
+        func = pysupport.importName("MoinMoin.stats." + args, "linkto")
+    except ImportError:
         return (formatter.sysmsg(1) +
-                formatter.text(_('Bad chart type "%s"!') % args) +
+                formatter.text(_('Bad chart type "%s"!', formatted=False) % args) +
                 formatter.sysmsg(0))
 
     return func(macro.formatter.page.page_name, macro.request)
