@@ -11,7 +11,9 @@
 
     Cleanup, fixed typos, PEP-8, support for limiting creation of threads,
     limited number of requests lifetime, configurable backlog for socket
-    .listen() by Thomas Waldmann <tw AT waldmann-edv DOT de>
+    .listen() by MoinMoin:ThomasWaldmann.
+
+    2007 Support for Python's logging module by MoinMoin:ThomasWaldmann.
 
     For code base see:
     http://cvs.lysator.liu.se/viewcvs/viewcvs.cgi/webkom/thfcgi.py?cvsroot=webkom
@@ -30,13 +32,11 @@
     Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 """
 
-# TODO:
-#
-# Compare compare the number of bytes received on FCGI_STDIN with
-# CONTENT_LENGTH and abort the update if the two numbers are not equal.
-#
+# TODO: Compare compare the number of bytes received on FCGI_STDIN with
+#       CONTENT_LENGTH and abort the update if the two numbers are not equal.
 
-debug = False
+import logging
+LOGLEVEL = logging.DEBUG # logging.NOTSET to completely switch it off
 
 import os
 import sys
@@ -99,12 +99,9 @@ FCGI_Record_header = "!BBHHBx"
 FCGI_UnknownTypeBody = "!B7x"
 FCGI_EndRequestBody = "!IB3x"
 
-LOGFILE = sys.stderr
 
 def log(s):
-    if debug:
-        LOGFILE.write(s)
-        LOGFILE.write('\n')
+    logging.log(LOGLEVEL, 'thfcgi: %s' % s)
 
 class SocketErrorOnWrite:
     """Is raised if a write fails in the socket code."""
@@ -223,7 +220,7 @@ class Record:
 
         elif self.rec_type == FCGI_GET_VALUES or self.rec_type == FCGI_PARAMS:
             content = ""
-            for i in self.values.keys():
+            for i in self.values:
                 content = content + self.write_pair(i, self.values[i])
 
         elif self.rec_type == FCGI_END_REQUEST:
@@ -410,8 +407,8 @@ class Request:
                       'FCGI_MPXS_CONNS': FCGI_MPXS_CONNS,
                      }
 
-            for name in rec.values.keys():
-                if params.has_key(name):
+            for name in rec.values:
+                if name in params:
                     # We known this value, include in reply
                     reply_rec.values[name] = params[name]
 
@@ -574,7 +571,7 @@ class FCGI:
     def _check_good_addrs(self, addr):
         """Check if request is done from the right server."""
         # Apaches mod_fastcgi seems not to use FCGI_WEB_SERVER_ADDRS. 
-        if os.environ.has_key('FCGI_WEB_SERVER_ADDRS'):
+        if 'FCGI_WEB_SERVER_ADDRS' in os.environ:
             good_addrs = os.environ['FCGI_WEB_SERVER_ADDRS'].split(',')
             good_addrs = [addr.strip() for addr in good_addrs] # Remove whitespace
         else:
@@ -587,11 +584,13 @@ class FCGI:
     def run(self):
         """Wait & serve. Calls request_handler on every request."""
         self.sock.listen(self.backlog)
-        log("Starting Process")
+        pid = os.getpid()
+        log("Starting Process (PID=%d)" % pid)
         running = True
         while running:
             if not self.requests_left:
                 # self.sock.shutdown(RDWR) here does NOT help with backlog
+                log("Maximum number of processed requests reached, terminating this worker process (PID=%d)..." % pid)
                 running = False
             elif self.requests_left > 0:
                 self.requests_left -= 1
@@ -599,13 +598,12 @@ class FCGI:
                 conn, addr = self.sock.accept()
                 threadcount = _threading.activeCount()
                 if threadcount < self.max_threads:
-                    log("Accepted connection, starting thread...")
+                    log("Accepted connection, %d active threads, starting worker thread..." % threadcount)
                     t = _threading.Thread(target=self.accept_handler, args=(conn, addr, True))
                     t.start()
                 else:
-                    log("Accepted connection, running in main-thread...")
+                    log("Accepted connection, %d active threads, running in main thread..." % threadcount)
                     self.accept_handler(conn, addr, False)
-                log("Active Threads: %d" % _threading.activeCount())
         self.sock.close()
-        log("Ending Process")
+        log("Ending Process (PID=%d)" % pid)
 
