@@ -3,18 +3,20 @@
 """
     MoinMoin - Version Information
 
-    @copyright: 2000-2006 by Jrgen Hermann <jh@web.de>
+    @copyright: 2000-2006 Juergen Hermann <jh@web.de>,
+                2003-2008 MoinMoin:ThomasWaldmann
     @license: GNU GPL, see COPYING for details.
 """
 import sys
 
 try:
-    from patchlevel import patchlevel
+    from MoinMoin.patchlevel import patchlevel
 except:
     patchlevel = 'release'
 
 project = "MoinMoin"
-release = '1.5.7'
+release = '1.6.3'
+release_short = '163' # used for url_prefix_static
 revision = patchlevel
 
 def update():
