@@ -22,6 +22,8 @@
     look into INSTALL.html to see how you can fix the bug on your own
     (a simple one line change).
 
+    TODO: this should be refactored so it uses MoinMoin.server package
+          (see how server_twisted, server_wsgi and server_standalone use it)
 
     @copyright: 2004-2005 by Oliver Graf <ograf@bitart.de>
     @license: GNU GPL, see COPYING for details.
@@ -31,14 +33,14 @@
 
 import sys
 
-# Path to MoinMoin package, needed if you installed with --prefix=PREFIX
-# or if you did not use setup.py.
-## sys.path.insert(0, 'PREFIX/lib/python2.3/site-packages')
-
 # Path of the directory where wikiconfig.py is located.
 # YOU NEED TO CHANGE THIS TO MATCH YOUR SETUP.
 sys.path.insert(0, '/path/to/wikiconfig')
 
+# Path to MoinMoin package, needed if you installed with --prefix=PREFIX
+# or if you did not use setup.py.
+## sys.path.insert(0, 'PREFIX/lib/python2.3/site-packages')
+
 # Path of the directory where farmconfig is located (if different).
 ## sys.path.insert(0, '/path/to/farmconfig')
 
@@ -46,17 +48,23 @@ sys.path.insert(0, '/path/to/wikiconfig')
 ## import os
 ## os.environ['MOIN_DEBUG'] = '1'
 
-# Set threads flag, so other code can use proper locking.
-# TODO: It seems that modpy does not use threads, so we don't need to
-# set it here. Do we have another method to check this?
-from MoinMoin import config
-config.use_threads = 1
-del config
+# Simple way
+#from MoinMoin.server.server_modpython import modpythonHandler as handler
 
+# Complex way
+from MoinMoin.server.server_modpython import ModpythonConfig, modpythonHandler
 
-from MoinMoin.request import RequestModPy
+class MyConfig(ModpythonConfig):
+    """ Set up local server-specific stuff here """
+
+    # Make sure moin will have permission to write to this file!
+    # Otherwise it will cause a server error.
+    logPath = "/var/log/apache2/moinlog"
+    
+    # Properties
+    # Allow overriding any request property by the value defined in
+    # this dict e.g properties = {'script_name': '/mywiki'}.
+    ## properties = {}
 
 def handler(request):
-    moinreq = RequestModPy(request)
-    return moinreq.run(request)
-
+    return modpythonHandler(request, MyConfig)
